summaryrefslogtreecommitdiffstats
path: root/org/madore/damlengine/TodoWrefAttr.java
diff options
context:
space:
mode:
Diffstat (limited to 'org/madore/damlengine/TodoWrefAttr.java')
-rw-r--r--org/madore/damlengine/TodoWrefAttr.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/org/madore/damlengine/TodoWrefAttr.java b/org/madore/damlengine/TodoWrefAttr.java
index 650297c..a2b67ac 100644
--- a/org/madore/damlengine/TodoWrefAttr.java
+++ b/org/madore/damlengine/TodoWrefAttr.java
@@ -70,8 +70,8 @@ public class TodoWrefAttr extends TodoAttr {
wrefNumberStr, wrefSupplementStr);
// Decide whether link target is on this page
final boolean onThisPage;
- if ( lk.singlePage != null && ! lk.supplementStr.equals("") ) {
- // Linking to a _fragment_ of an entry that has a single page.
+ if ( esum != null && esum.hasCut && ! lk.supplementStr.equals("") ) {
+ // Linking to a _fragment_ of an entry that has a cut-here element.
if ( ctx.wsc != null && ctx.wsc.sel != null
&& ctx.wsc instanceof Context.WeblogSingleSelectionContext
&& ((Context.WeblogSingleSelectionContext)ctx.wsc).number == wrefNumber )